==> aom-docs-3.2.0-1-aarch64.pkg.tar.xz: usr/share/doc/aom/annotated_dup.js <==
var annotated_dup =
[
    [ "AlgoCfg", "structAlgoCfg.html", "structAlgoCfg" ],
    [ "aom_active_map", "structaom__active__map.html", "structaom__active__map" ],
    [ "aom_codec_ctx", "structaom__codec__ctx.html", "structaom__codec__ctx" ],
    [ "aom_codec_cx_pkt", "structaom__codec__cx__pkt.html", "structaom__codec__cx__pkt" ],
    [ "aom_codec_dec_cfg", "structaom__codec__dec__cfg.html", "structaom__codec__dec__cfg" ],
    [ "aom_codec_enc_cfg", "structaom__codec__enc__cfg.html", "structaom__codec__enc__cfg" ],
    [ "aom_codec_frame_buffer", "structaom__codec__frame__buffer.html", "structaom__codec__frame__buffer" ],
    [ "aom_codec_stream_info", "structaom__codec__stream__info.html", "structaom__codec__stream__info" ],
    [ "aom_ext_part_config", "structaom__ext__part__config.html", "structaom__ext__part__config" ],
    [ "aom_ext_part_funcs", "structaom__ext__part__funcs.html", "structaom__ext__part__funcs" ],
    [ "aom_fixed_buf", "structaom__fixed__buf.html", "structaom__fixed__buf" ],
    [ "aom_image", "structaom__image.html", "structaom__image" ],
    [ "aom_inspect_init", "structaom__inspect__init.html", "structaom__inspect__init" ],
    [ "aom_metadata", "structaom__metadata.html", "structaom__metadata" ],
    [ "aom_partition_decision", "structaom__partition__decision.html", "structaom__partition__decision" ],
    [ "aom_partition_features", "structaom__partition__features.html", "structaom__partition__features" ],
    [ "aom_partition_features_ab", "structaom__partition__features__ab.html", "structaom__partition__features__ab" ],
    [ "aom_partition_features_before_none", "structaom__partition__features__before__none.html", "structaom__partition__features__before__none" ],
    [ "aom_partition_features_none", "structaom__partition__features__none.html", "structaom__partition__features__none" ],
    [ "aom_partition_features_rect", "structaom__partition__features__rect.html", "structaom__partition__features__rect" ],
    [ "aom_partition_features_split", "structaom__partition__features__split.html", "structaom__partition__features__split" ],
    [ "aom_partition_stats", "structaom__partition__stats.html", "structaom__partition__stats" ],
    [ "aom_rational", "structaom__rational.html", "structaom__rational" ],
    [ "aom_roi_map", "structaom__roi__map.html", "structaom__roi__map" ],
    [ "aom_s_frame_info", "structaom__s__frame__info.html", "structaom__s__frame__info" ],
    [ "aom_sb_features", "structaom__sb__features.html", "structaom__sb__features" ],
    [ "aom_sb_simple_motion_features", "structaom__sb__simple__motion__features.html", "structaom__sb__simple__motion__features" ],
    [ "aom_sb_tpl_features", "structaom__sb__tpl__features.html", "structaom__sb__tpl__features" ],
    [ "aom_scaling_mode", "structaom__scaling__mode.html", "structaom__scaling__mode" ],
    [ "aom_screen_content_tools_info", "structaom__screen__content__tools__info.html", "structaom__screen__content__tools__info" ],
    [ "aom_still_picture_info", "structaom__still__picture__info.html", "structaom__still__picture__info" ],
    [ "aom_svc_layer_id", "structaom__svc__layer__id.html", "structaom__svc__layer__id" ],
    [ "aom_svc_params", "structaom__svc__params.html", "structaom__svc__params" ],
    [ "aom_svc_ref_frame_comp_pred", "structaom__svc__ref__frame__comp__pred.html", "structaom__svc__ref__frame__comp__pred" ],
    [ "aom_svc_ref_frame_config", "structaom__svc__ref__frame__config.html", "structaom__svc__ref__frame__config" ],
    [ "aom_tile_data", "structaom__tile__data.html", "structaom__tile__data" ],
    [ "aom_tile_info", "structaom__tile__info.html", "structaom__tile__info" ],
    [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
    [ "AV1_COMP_DATA", "structAV1__COMP__DATA.html", "structAV1__COMP__DATA" ],
    [ "av1_ext_ref_frame", "structav1__ext__ref__frame.html", "structav1__ext__ref__frame" ],
    [ "AV1_PRIMARY", "structAV1__PRIMARY.html", "structAV1__PRIMARY" ],
    [ "av1_ref_frame", "structav1__ref__frame.html", "structav1__ref__frame" ],
    [ "AV1Common", "structAV1Common.html", "structAV1Common" ],
    [ "Av1DecodeReturn", "structAv1DecodeReturn.html", "structAv1DecodeReturn" ],
    [ "AV1EncoderConfig", "structAV1EncoderConfig.html", "structAV1EncoderConfig" ],
    [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
    [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
    [ "CB_COEFF_BUFFER", "structCB__COEFF__BUFFER.html", "structCB__COEFF__BUFFER" ],
    [ "CdefBlockInfo", "structCdefBlockInfo.html", "structCdefBlockInfo" ],
    [ "CdefInfo", "structCdefInfo.html", "structCdefInfo" ],
    [ "cfg_options", "structcfg__options.html", "structcfg__options" ],
    [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
    [ "CoeffCosts", "structCoeffCosts.html", "structCoeffCosts" ],
    [ "CommonContexts", "structCommonContexts.html", "structCommonContexts" ],
    [ "CommonModeInfoParams", "structCommonModeInfoParams.html", "structCommonModeInfoParams" ],
    [ "CommonQuantParams", "structCommonQuantParams.html", "structCommonQuantParams" ],
    [ "CommonTileParams", "structCommonTileParams.html", "structCommonTileParams" ],
    [ "COMP_RD_STATS", "structCOMP__RD__STATS.html", "structCOMP__RD__STATS" ],
    [ "CompoundTypeCfg", "structCompoundTypeCfg.html", "structCompoundTypeCfg" ],
    [ "CompoundTypeRdBuffers", "structCompoundTypeRdBuffers.html", "structCompoundTypeRdBuffers" ],
    [ "CYCLIC_REFRESH", "structCYCLIC__REFRESH.html", "structCYCLIC__REFRESH" ],
    [ "DecoderCodingBlock", "structDecoderCodingBlock.html", "structDecoderCodingBlock" ],
    [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
    [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
    [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
    [ "ExternalFlags", "structExternalFlags.html", "structExternalFlags" ],
    [ "ExtRefreshFrameFlagsInfo", "structExtRefreshFrameFlagsInfo.html", "structExtRefreshFrameFlagsInfo" ],
    [ "FeatureFlags", "structFeatureFlags.html", "structFeatureFlags" ],
    [ "FIRST_PASS_SPEED_FEATURES", "structFIRST__PASS__SPEED__FEATURES.html", "structFIRST__PASS__SPEED__FEATURES" ],
    [ "FIRSTPASS_INFO", "structFIRSTPASS__INFO.html", "structFIRSTPASS__INFO" ],
    [ "FIRSTPASS_STATS", "structFIRSTPASS__STATS.html", "structFIRSTPASS__STATS" ],
    [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
    [ "FrameProbInfo", "structFrameProbInfo.html", "structFrameProbInfo" ],
    [ "GF_FRAME_STATS", "structGF__FRAME__STATS.html", null ],
    [ "GF_GROUP", "structGF__GROUP.html", null ],
    [ "GF_GROUP_STATS", "structGF__GROUP__STATS.html", null ],
    [ "GlobalMotionInfo", "structGlobalMotionInfo.html", "structGlobalMotionInfo" ],
    [ "HIGH_LEVEL_SPEED_FEATURES", "structHIGH__LEVEL__SPEED__FEATURES.html", "structHIGH__LEVEL__SPEED__FEATURES" ],
    [ "InitialDimensions", "structInitialDimensions.html", "structInitialDimensions" ],
    [ "inter_modes_info", "structinter__modes__info.html", "structinter__modes__info" ],
    [ "InterpSearchFlags", "structInterpSearchFlags.html", "structInterpSearchFlags" ],
    [ "IntraBCMVCosts", "structIntraBCMVCosts.html", "structIntraBCMVCosts" ],
    [ "IntraModeCfg", "structIntraModeCfg.html", "structIntraModeCfg" ],
    [ "IntraModeSearchState", "structIntraModeSearchState.html", "structIntraModeSearchState" ],
    [ "KeyFrameCfg", "structKeyFrameCfg.html", "structKeyFrameCfg" ],
    [ "LAYER_CONTEXT", "structLAYER__CONTEXT.html", "structLAYER__CONTEXT" ],
    [ "LV_MAP_COEFF_COST", "structLV__MAP__COEFF__COST.html", "structLV__MAP__COEFF__COST" ],
    [ "LV_MAP_EOB_COST", "structLV__MAP__EOB__COST.html", "structLV__MAP__EOB__COST" ],
    [ "macroblock", "structmacroblock.html", "structmacroblock" ],
    [ "macroblock_plane", "structmacroblock__plane.html", "structmacroblock__plane" ],
    [ "macroblockd", "structmacroblockd.html", "structmacroblockd" ],
    [ "MB_MODE_INFO", "structMB__MODE__INFO.html", "structMB__MODE__INFO" ],
    [ "MB_MODE_INFO_EXT", "structMB__MODE__INFO__EXT.html", "structMB__MODE__INFO__EXT" ],
    [ "MB_MODE_INFO_EXT_FRAME", "structMB__MODE__INFO__EXT__FRAME.html", "structMB__MODE__INFO__EXT__FRAME" ],
    [ "MB_RD_INFO", "structMB__RD__INFO.html", "structMB__RD__INFO" ],
    [ "MB_RD_RECORD", "structMB__RD__RECORD.html", "structMB__RD__RECORD" ],
    [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
    [ "ModeCosts", "structModeCosts.html", "structModeCosts" ],
    [ "motion_mode_candidate", "structmotion__mode__candidate.html", "structmotion__mode__candidate" ],
    [ "MotionVectorSearchParams", "structMotionVectorSearchParams.html", "structMotionVectorSearchParams" ],
    [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
    [ "MvCosts", "structMvCosts.html", "structMvCosts" ],
    [ "OBMCBuffer", "structOBMCBuffer.html", "structOBMCBuffer" ],
    [ "PALETTE_BUFFER", "structPALETTE__BUFFER.html", "structPALETTE__BUFFER" ],
    [ "PartitionCfg", "structPartitionCfg.html", "structPartitionCfg" ],
    [ "PartitionSearchInfo", "structPartitionSearchInfo.html", "structPartitionSearchInfo" ],
    [ "PRIMARY_RATE_CONTROL", "structPRIMARY__RATE__CONTROL.html", "structPRIMARY__RATE__CONTROL" ],
    [ "PrimaryMultiThreadInfo", "structPrimaryMultiThreadInfo.html", "structPrimaryMultiThreadInfo" ],
    [ "PruneInfoFromTpl", "structPruneInfoFromTpl.html", "structPruneInfoFromTpl" ],
    [ "RATE_CONTROL", "structRATE__CONTROL.html", "structRATE__CONTROL" ],
    [ "RateControlCfg", "structRateControlCfg.html", "structRateControlCfg" ],
    [ "RefFrameDistanceInfo", "structRefFrameDistanceInfo.html", "structRefFrameDistanceInfo" ],
    [ "RefreshFrameFlagsInfo", "structRefreshFrameFlagsInfo.html", "structRefreshFrameFlagsInfo" ],
    [ "ResizeCfg", "structResizeCfg.html", "structResizeCfg" ],
    [ "ResizePendingParams", "structResizePendingParams.html", "structResizePendingParams" ],
    [ "RestorationInfo", "structRestorationInfo.html", "structRestorationInfo" ],
    [ "RestorationStripeBoundaries", "structRestorationStripeBoundaries.html", "structRestorationStripeBoundaries" ],
    [ "RestorationUnitInfo", "structRestorationUnitInfo.html", "structRestorationUnitInfo" ],
    [ "SgrprojInfo", "structSgrprojInfo.html", "structSgrprojInfo" ],
    [ "SPEED_FEATURES", "structSPEED__FEATURES.html", "structSPEED__FEATURES" ],
    [ "SuperBlockEnc", "structSuperBlockEnc.html", "structSuperBlockEnc" ],
    [ "SuperResCfg", "structSuperResCfg.html", "structSuperResCfg" ],
    [ "SVC", "structSVC.html", "structSVC" ],
    [ "TemporalFilterCtx", "structTemporalFilterCtx.html", "structTemporalFilterCtx" ],
    [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
    [ "TplParams", "structTplParams.html", "structTplParams" ],
    [ "TWO_PASS", "structTWO__PASS.html", null ],
    [ "TWO_PASS_FRAME", "structTWO__PASS__FRAME.html", null ],
    [ "TXB_RD_INFO", "structTXB__RD__INFO.html", "structTXB__RD__INFO" ],
    [ "TXB_RD_RECORD", "structTXB__RD__RECORD.html", "structTXB__RD__RECORD" ],
    [ "TxbRdRecords", "structTxbRdRecords.html", "structTxbRdRecords" ],
    [ "TxfmSearchInfo", "structTxfmSearchInfo.html", "structTxfmSearchInfo" ],
    [ "TxfmSearchParams", "structTxfmSearchParams.html", "structTxfmSearchParams" ],
    [ "TxfmSizeTypeCfg", "structTxfmSizeTypeCfg.html", "structTxfmSizeTypeCfg" ],
    [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
    [ "WARP_SAMPLE_INFO", "structWARP__SAMPLE__INFO.html", "structWARP__SAMPLE__INFO" ],
    [ "WienerInfo", "structWienerInfo.html", "structWienerInfo" ],
    [ "WinnerModeParams", "structWinnerModeParams.html", "structWinnerModeParams" ],
    [ "WinnerModeStats", "structWinnerModeStats.html", "structWinnerModeStats" ],
    [ "yv12_buffer_config", "structyv12__buffer__config.html", null ]
];

==> aom-docs-3.8.1-1-aarch64.pkg.tar.xz: usr/share/doc/aom/annotated_dup.js <==
var annotated_dup =
[
    [ "AlgoCfg", "structAlgoCfg.html", "structAlgoCfg" ],
    [ "aom_active_map", "structaom__active__map.html", "structaom__active__map" ],
    [ "aom_codec_ctx", "structaom__codec__ctx.html", "structaom__codec__ctx" ],
    [ "aom_codec_cx_pkt", "structaom__codec__cx__pkt.html", "structaom__codec__cx__pkt" ],
    [ "aom_codec_dec_cfg", "structaom__codec__dec__cfg.html", "structaom__codec__dec__cfg" ],
    [ "aom_codec_enc_cfg", "structaom__codec__enc__cfg.html", "structaom__codec__enc__cfg" ],
    [ "aom_codec_frame_buffer", "structaom__codec__frame__buffer.html", "structaom__codec__frame__buffer" ],
    [ "aom_codec_stream_info", "structaom__codec__stream__info.html", "structaom__codec__stream__info" ],
    [ "aom_ext_part_config", "structaom__ext__part__config.html", "structaom__ext__part__config" ],
    [ "aom_ext_part_funcs", "structaom__ext__part__funcs.html", "structaom__ext__part__funcs" ],
    [ "aom_fixed_buf", "structaom__fixed__buf.html", "structaom__fixed__buf" ],
    [ "aom_image", "structaom__image.html", "structaom__image" ],
    [ "aom_inspect_init", "structaom__inspect__init.html", "structaom__inspect__init" ],
    [ "aom_metadata", "structaom__metadata.html", "structaom__metadata" ],
    [ "aom_partition_decision", "structaom__partition__decision.html", "structaom__partition__decision" ],
    [ "aom_partition_features", "structaom__partition__features.html", "structaom__partition__features" ],
    [ "aom_partition_features_ab", "structaom__partition__features__ab.html", "structaom__partition__features__ab" ],
    [ "aom_partition_features_before_none", "structaom__partition__features__before__none.html", "structaom__partition__features__before__none" ],
    [ "aom_partition_features_none", "structaom__partition__features__none.html", "structaom__partition__features__none" ],
    [ "aom_partition_features_rect", "structaom__partition__features__rect.html", "structaom__partition__features__rect" ],
    [ "aom_partition_features_split", "structaom__partition__features__split.html", "structaom__partition__features__split" ],
    [ "aom_partition_stats", "structaom__partition__stats.html", "structaom__partition__stats" ],
    [ "aom_rational", "structaom__rational.html", "structaom__rational" ],
    [ "aom_roi_map", "structaom__roi__map.html", "structaom__roi__map" ],
    [ "aom_s_frame_info", "structaom__s__frame__info.html", "structaom__s__frame__info" ],
    [ "aom_sb_features", "structaom__sb__features.html", "structaom__sb__features" ],
    [ "aom_sb_simple_motion_features", "structaom__sb__simple__motion__features.html", "structaom__sb__simple__motion__features" ],
    [ "aom_sb_tpl_features", "structaom__sb__tpl__features.html", "structaom__sb__tpl__features" ],
    [ "aom_scaling_mode", "structaom__scaling__mode.html", "structaom__scaling__mode" ],
    [ "aom_screen_content_tools_info", "structaom__screen__content__tools__info.html", "structaom__screen__content__tools__info" ],
    [ "aom_still_picture_info", "structaom__still__picture__info.html", "structaom__still__picture__info" ],
    [ "aom_svc_layer_id", "structaom__svc__layer__id.html", "structaom__svc__layer__id" ],
    [ "aom_svc_params", "structaom__svc__params.html", "structaom__svc__params" ],
    [ "aom_svc_ref_frame_comp_pred", "structaom__svc__ref__frame__comp__pred.html", "structaom__svc__ref__frame__comp__pred" ],
    [ "aom_svc_ref_frame_config", "structaom__svc__ref__frame__config.html", "structaom__svc__ref__frame__config" ],
    [ "aom_tile_data", "structaom__tile__data.html", "structaom__tile__data" ],
    [ "aom_tile_info", "structaom__tile__info.html", "structaom__tile__info" ],
    [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
    [ "AV1_COMP_DATA", "structAV1__COMP__DATA.html", "structAV1__COMP__DATA" ],
    [ "av1_ext_ref_frame", "structav1__ext__ref__frame.html", "structav1__ext__ref__frame" ],
    [ "AV1_PRIMARY", "structAV1__PRIMARY.html", "structAV1__PRIMARY" ],
    [ "av1_ref_frame", "structav1__ref__frame.html", "structav1__ref__frame" ],
    [ "AV1Common", "structAV1Common.html", "structAV1Common" ],
    [ "Av1DecodeReturn", "structAv1DecodeReturn.html", "structAv1DecodeReturn" ],
    [ "AV1EncAllIntraMultiThreadInfo", "structAV1EncAllIntraMultiThreadInfo.html", "structAV1EncAllIntraMultiThreadInfo" ],
    [ "AV1EncoderConfig", "structAV1EncoderConfig.html", "structAV1EncoderConfig" ],
    [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
    [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
    [ "AV1LrPickStruct", "structAV1LrPickStruct.html", "structAV1LrPickStruct" ],
    [ "CB_COEFF_BUFFER", "structCB__COEFF__BUFFER.html", "structCB__COEFF__BUFFER" ],
    [ "CdefBlockInfo", "structCdefBlockInfo.html", "structCdefBlockInfo" ],
    [ "CdefInfo", "structCdefInfo.html", "structCdefInfo" ],
    [ "cfg_options", "structcfg__options.html", "structcfg__options" ],
    [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
    [ "CoeffCosts", "structCoeffCosts.html", "structCoeffCosts" ],
    [ "ColorCount", "structColorCount.html", "structColorCount" ],
    [ "CommonContexts", "structCommonContexts.html", "structCommonContexts" ],
    [ "CommonModeInfoParams", "structCommonModeInfoParams.html", "structCommonModeInfoParams" ],
    [ "CommonQuantParams", "structCommonQuantParams.html", "structCommonQuantParams" ],
    [ "CommonTileParams", "structCommonTileParams.html", "structCommonTileParams" ],
    [ "COMP_RD_STATS", "structCOMP__RD__STATS.html", "structCOMP__RD__STATS" ],
    [ "CompoundTypeCfg", "structCompoundTypeCfg.html", "structCompoundTypeCfg" ],
    [ "CompoundTypeRdBuffers", "structCompoundTypeRdBuffers.html", "structCompoundTypeRdBuffers" ],
    [ "CYCLIC_REFRESH", "structCYCLIC__REFRESH.html", "structCYCLIC__REFRESH" ],
    [ "DecoderCodingBlock", "structDecoderCodingBlock.html", "structDecoderCodingBlock" ],
    [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
    [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
    [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
    [ "ExternalFlags", "structExternalFlags.html", "structExternalFlags" ],
    [ "ExtRefreshFrameFlagsInfo", "structExtRefreshFrameFlagsInfo.html", "structExtRefreshFrameFlagsInfo" ],
    [ "FeatureFlags", "structFeatureFlags.html", "structFeatureFlags" ],
    [ "FIRST_PASS_SPEED_FEATURES", "structFIRST__PASS__SPEED__FEATURES.html", "structFIRST__PASS__SPEED__FEATURES" ],
    [ "FIRSTPASS_INFO", "structFIRSTPASS__INFO.html", "structFIRSTPASS__INFO" ],
    [ "FIRSTPASS_STATS", "structFIRSTPASS__STATS.html", "structFIRSTPASS__STATS" ],
    [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
    [ "FrameProbInfo", "structFrameProbInfo.html", "structFrameProbInfo" ],
    [ "GF_FRAME_STATS", "structGF__FRAME__STATS.html", null ],
    [ "GF_GROUP", "structGF__GROUP.html", null ],
    [ "GF_GROUP_STATS", "structGF__GROUP__STATS.html", null ],
    [ "GlobalMotionInfo", "structGlobalMotionInfo.html", "structGlobalMotionInfo" ],
    [ "HIGH_LEVEL_SPEED_FEATURES", "structHIGH__LEVEL__SPEED__FEATURES.html", "structHIGH__LEVEL__SPEED__FEATURES" ],
    [ "InitialDimensions", "structInitialDimensions.html", "structInitialDimensions" ],
    [ "inter_modes_info", "structinter__modes__info.html", "structinter__modes__info" ],
    [ "InterModeSearchStateNonrd", "structInterModeSearchStateNonrd.html", "structInterModeSearchStateNonrd" ],
    [ "InterpSearchFlags", "structInterpSearchFlags.html", "structInterpSearchFlags" ],
    [ "IntraBCMVCosts", "structIntraBCMVCosts.html", "structIntraBCMVCosts" ],
    [ "IntraModeCfg", "structIntraModeCfg.html", "structIntraModeCfg" ],
    [ "IntraModeSearchState", "structIntraModeSearchState.html", "structIntraModeSearchState" ],
    [ "KeyFrameCfg", "structKeyFrameCfg.html", "structKeyFrameCfg" ],
    [ "LAYER_CONTEXT", "structLAYER__CONTEXT.html", "structLAYER__CONTEXT" ],
    [ "LV_MAP_COEFF_COST", "structLV__MAP__COEFF__COST.html", "structLV__MAP__COEFF__COST" ],
    [ "LV_MAP_EOB_COST", "structLV__MAP__EOB__COST.html", "structLV__MAP__EOB__COST" ],
    [ "macroblock", "structmacroblock.html", "structmacroblock" ],
    [ "macroblock_plane", "structmacroblock__plane.html", "structmacroblock__plane" ],
    [ "macroblockd", "structmacroblockd.html", "structmacroblockd" ],
    [ "MB_MODE_INFO", "structMB__MODE__INFO.html", "structMB__MODE__INFO" ],
    [ "MB_MODE_INFO_EXT", "structMB__MODE__INFO__EXT.html", "structMB__MODE__INFO__EXT" ],
    [ "MB_MODE_INFO_EXT_FRAME", "structMB__MODE__INFO__EXT__FRAME.html", "structMB__MODE__INFO__EXT__FRAME" ],
    [ "MB_RD_INFO", "structMB__RD__INFO.html", "structMB__RD__INFO" ],
    [ "MB_RD_RECORD", "structMB__RD__RECORD.html", "structMB__RD__RECORD" ],
    [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
    [ "ModeCosts", "structModeCosts.html", "structModeCosts" ],
    [ "motion_mode_candidate", "structmotion__mode__candidate.html", "structmotion__mode__candidate" ],
    [ "MotionVectorSearchParams", "structMotionVectorSearchParams.html", "structMotionVectorSearchParams" ],
    [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
    [ "MvCosts", "structMvCosts.html", "structMvCosts" ],
    [ "OBMCBuffer", "structOBMCBuffer.html", "structOBMCBuffer" ],
    [ "PALETTE_BUFFER", "structPALETTE__BUFFER.html", "structPALETTE__BUFFER" ],
    [ "PartitionCfg", "structPartitionCfg.html", "structPartitionCfg" ],
    [ "PartitionSearchInfo", "structPartitionSearchInfo.html", "structPartitionSearchInfo" ],
    [ "PRIMARY_RATE_CONTROL", "structPRIMARY__RATE__CONTROL.html", "structPRIMARY__RATE__CONTROL" ],
    [ "PrimaryMultiThreadInfo", "structPrimaryMultiThreadInfo.html", "structPrimaryMultiThreadInfo" ],
    [ "PruneInfoFromTpl", "structPruneInfoFromTpl.html", "structPruneInfoFromTpl" ],
    [ "RATE_CONTROL", "structRATE__CONTROL.html", "structRATE__CONTROL" ],
    [ "RateControlCfg", "structRateControlCfg.html", "structRateControlCfg" ],
    [ "RefFrameDistanceInfo", "structRefFrameDistanceInfo.html", "structRefFrameDistanceInfo" ],
    [ "RefreshFrameInfo", "structRefreshFrameInfo.html", "structRefreshFrameInfo" ],
    [ "ResizeCfg", "structResizeCfg.html", "structResizeCfg" ],
    [ "ResizePendingParams", "structResizePendingParams.html", "structResizePendingParams" ],
    [ "RestorationInfo", "structRestorationInfo.html", "structRestorationInfo" ],
    [ "RestorationStripeBoundaries", "structRestorationStripeBoundaries.html", "structRestorationStripeBoundaries" ],
    [ "RestorationUnitInfo", "structRestorationUnitInfo.html", "structRestorationUnitInfo" ],
    [ "RestoreStateBuffers", "structRestoreStateBuffers.html", "structRestoreStateBuffers" ],
    [ "RestUnitSearchInfo", "structRestUnitSearchInfo.html", "structRestUnitSearchInfo" ],
    [ "SgrprojInfo", "structSgrprojInfo.html", "structSgrprojInfo" ],
    [ "SPEED_FEATURES", "structSPEED__FEATURES.html", "structSPEED__FEATURES" ],
    [ "SuperBlockEnc", "structSuperBlockEnc.html", "structSuperBlockEnc" ],
    [ "SuperResCfg", "structSuperResCfg.html", "structSuperResCfg" ],
    [ "SVC", "structSVC.html", "structSVC" ],
    [ "TEMPORAL_FILTER_INFO", "structTEMPORAL__FILTER__INFO.html", "structTEMPORAL__FILTER__INFO" ],
    [ "TemporalFilterCtx", "structTemporalFilterCtx.html", "structTemporalFilterCtx" ],
    [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
    [ "TplParams", "structTplParams.html", "structTplParams" ],
    [ "TWO_PASS", "structTWO__PASS.html", null ],
    [ "TWO_PASS_FRAME", "structTWO__PASS__FRAME.html", null ],
    [ "TxfmSearchInfo", "structTxfmSearchInfo.html", "structTxfmSearchInfo" ],
    [ "TxfmSearchParams", "structTxfmSearchParams.html", "structTxfmSearchParams" ],
    [ "TxfmSizeTypeCfg", "structTxfmSizeTypeCfg.html", "structTxfmSizeTypeCfg" ],
    [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
    [ "WARP_SAMPLE_INFO", "structWARP__SAMPLE__INFO.html", "structWARP__SAMPLE__INFO" ],
    [ "WienerInfo", "structWienerInfo.html", "structWienerInfo" ],
    [ "WinnerModeParams", "structWinnerModeParams.html", "structWinnerModeParams" ],
    [ "WinnerModeStats", "structWinnerModeStats.html", "structWinnerModeStats" ],
    [ "yv12_buffer_config", "structyv12__buffer__config.html", null ]
];
